IDExtractedModel class
Constructors
-
IDExtractedModel({required Map<
String, dynamic> extractedData, required List<String> faces, required IdentificationDocumentCapture identificationDocumentCapture, required String imageUrl, required Map<String, dynamic> outputProperties, required Map<String, String> transformedProperties}) -
IDExtractedModel.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
extractedData
→ Map<
String, dynamic> -
final
-
faces
→ List<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- identificationDocumentCapture → IdentificationDocumentCapture
-
final
- imageUrl → String
-
final
-
outputProperties
→ Map<
String, dynamic> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
transformedProperties
→ Map<
String, String> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited